function [xc,mc] = cauchy(xn,fx,gx,H,delta)

% Compute the Cauchy point and the model function value at that point

% Auxiliary variables

curv = gx'*(H*gx);
nrm = norm(gx);
    
% Decide whether to chose the critical point or the point on the trust
% region boundary - note that the if statement I use automatically covers
% both the case that curv is not positive, as well as the case that
% delta/nrm < nrm^2/curv.

if curv > nrm^3/delta
    alpha = nrm^2/curv;
else
    alpha = delta/nrm;
end
   
% Set the Cauchy point

xc = xn  - alpha * gx;

% Evaluate the model at the Cauchy point
    
mc  = fx - alpha * nrm^2 + alpha^2/2 * curv;
    
end

