
function [x,n] = tr_basic(f,df,d2f,xn,delta,delmax,rho_ac,tol)

% Iterate up to a maximum of 10000 iterations

for n=0:10000
    
    x(:,n+1) = xn;

    % Evaluate the Gradient at the current point x
    
    gx = df(xn);
    
    % For the stopping criterion check whether the norm of the gradient is 
    % below the requested tolerance

    if norm(gx) < tol
        break
    end
    
    % Evaluate objective function and Hessian at the current point x
    
    fx = f(xn);
    H  = d2f(xn);
    
    % Compute the Cauchy point and evaluate the model at the Cauchy point
    
    [xc,mc] = cauchy(xn,fx,gx,H,delta);
    
    % Evaluate the model misfit rho_n
    
    rho = (fx - f(xc))/(fx - mc);
    
    % Decide whether to accept or reject the proposed new iterate
    
    if rho >= rho_ac
        xn = xc;
    end 
    
    % Adjust the trust region radius
        
    step = norm(xn-x(:,n+1));   
    if rho < 0.25
        delta = 0.25*delta;
    elseif (rho > 0.75) && (abs(step-delta) < 1.0e-10)
        delta = min(2*delta,delmax);
    end
    
end

end